package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````,"````````!``````````#BA````
M`````````$``.``'`$``%@`5``8````%````0`````````!``````````$``
M````````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!````````R`$````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````,B+````````R(L`````````
M``$```````$````&````:)L```````!HFP$``````&B;`0``````$`4`````
M``!P%0```````````0```````@````8```"`FP```````(";`0``````@)L!
M``````#@`0```````.`!````````"`````````!1Y71D!@``````````````
M```````````````````````````````````````````0`````````%+E=&0$
M````:)L```````!HFP$``````&B;`0``````F`0```````"8!`````````$`
M````````+VQI8B]L9"UM=7-L+6%A<F-H-C0N<V\N,0`````````1````4```
M``0````(````(0````7`!(`H`!`!@(9`@((A``0)``2)B(`80;H$`@A0````
M40```%4```!:````6P```&$```!B````8P````````!E``````````````!F
M````9P```&D```````````````&O-.AJ?YI\ZM/O#L[>1RUOQ=\?+L6;MKB-
M\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MOXD?&`5COEWF[XY)\5<,\
MTF>OS&:(!W#30T75[#-BV^U_J9R;X*<""K_:5QNCX/M)````````````````
M```````````````````````````#``<`&!H````````````````````````#
M``\`>)L!``````````````````P````2`````````````````````````.<!
M```2`````````````````````````!0````1````````````````````````
M``T"```1`````````````````````````(D!```2````````````````````
M`````!L````2`````````````````````````,8!```2````````````````
M`````````",````2`````````````````````````"H````2````````````
M`````````````!H"```2`````````````````````````-(!```2````````
M`````````````````#,````@`````````````````````````&0#```A````
M`````````````````````$L````2`````````````````````````%$````2
M`````````````````````````%@````2`````````````````````````"H#
M```2`````````````````````````!L#```2````````````````````````
M`)\"```2`````````````````````````%\````2````````````````````
M`````$`"```2`````````````````````````&8````2````````````````
M`````````-0"```2`````````````````````````&T````2````````````
M`````````````'4````@`````````````````````````(D````2````````
M`````````````````+T"```2`````````````````````````)$````2````
M`````````````````````)<````2`````````````````````````*`````@
M`````````````````````````!0#```2`````````````````````````+P`
M```2`````````````````````````,$````2````````````````````````
M`"L"```1`````````````````````````-L"```2````````````````````
M`````&T"```2`````````````````````````#H#```2````````````````
M`````````%\"```2`````````````````````````.`#```2````````````
M`````````````.8"```1`````````````````````````&,#```1````````
M`````````````````)$"```2`````````````````````````%`#```2````
M`````````````````````&4#```1`````````````````````````,@````2
M`````````````````````````$@#```2`````````````````````````-$`
M```1`````````````````````````)<!```2````````````````````````
M`.,````B`````````````````````````/(````@````````````````````
M``````@!```2``````````````````````````P#```2````````````````
M`````````'T"```2``````````````````````````T!```2````````````
M`````````````!,!```@`````````````````````````,@"```2````````
M`````````````````"T!```2`````````````````````````+<!```2````
M`````````````````````#(!```2`````````````````````````*T"```2
M`````````````````````````*8!```2`````````````````````````#@!
M```2`````````````````````````$D!```2````````````````````````
M`#L"```2`````````````````````````)(````2````````````````````
M`````$P"```2`````````````````````````(8"```2````````````````
M`````````$$#```2`````````````````````````$\!```2````````````
M`````````````#(#```2`````````````````````````&,!```2````````
M`````````````````#8"```2`````````````````````````/4!```2````
M`````````````````````&H!```2`````````````````````````'$!```2
M`````````````````````````&(#```A`````````````````````````((!
M```2`````````````````````````(\#```0`!,`V+`!````````````````
M`%T#```2``D`,!X``````````@````````<"```2``H`E$P````````$````
M`````"($```2``D`V#\````````,"0```````)@$```2``D`+$P```````!H
M`````````/\#```2``D`[#D````````$`````````#$$```2``<`&!H`````
M```$`````````$4$```2``D`Y$@```````!(`P```````(`#```0`!,`>*`!
M`````````````````(L$```2``D`\#D```````#H`0```````'0#```0`!,`
M>*`!`````````````````!`$```2``D`)#\```````"T`````````"\$```2
M``D`,#@````````X`````````#<$```2``D`H#X```````!<`````````&4$
M```2``D`V#L````````@`````````)H#```0`!,`V+`!````````````````
M`*(#```0`!,`V+`!`````````````````,4#```2``D`3"`````````P````
M`````'($```2``D`^#L````````$`0```````%L$```1`!(`<*`!```````(
M`````````&T#```0`!(`>*`!`````````````````'D#```2``D`,"``````
M`````````````,X#```2``D`_#X````````H`````````.D#```2``D`O#@`
M```````P`0```````(X#```0`!,`V+`!`````````````````'X$```2``D`
M_#P```````"D`0````````!L:6)P97)L+G-O`&]P96YD:7(`<W1D97)R`')E
M86QL;V,`86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O
M`&QS965K`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`%]*
M=E]296=I<W1E<D-L87-S97,`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-
M7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<F5A9&QI;FL`
M7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F
M<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!R96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G
M971S<&5C:69I8P!M96UC<'D`<W1R;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T
M=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?
M;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%]F:6YI
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO
M<GE?=W)A<`!L:6)C+FUU<VPM86%R8V@V-"YS;RXQ`&9P<FEN=&8`<W1R9'5P
M`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT9@!S=')C:'(`<W1R=&]K
M`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV:7)O;@!?961A=&$`
M7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?
M`%]E;F0`+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`7W-T87)T7V,`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK
M=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?
M:6YI=%]E;G8`<&%R7V9I;F1P<F]G`'!A<E]C;&5A;G5P``````!HFP$`````
M``,$````````4"$```````!PFP$```````,$````````Z"````````!PGP$`
M``````,$````````,!X```````"(GP$```````,$````````E$P```````"H
MGP$```````,$````````&!H`````````H`$```````,$`````````*`!````
M```0H`$```````,$````````B$\````````8H`$```````,$````````U4P`
M```````HH`$```````,$````````MDT````````PH`$```````,$````````
MKTT````````XH`$```````,$````````?$\```````!`H`$```````,$````
M````S$T```````!(H`$```````,$````````A$\```````!8H`$```````,$
M````````;D\```````!@H`$```````,$````````<T\```````!PH`$`````
M``,$````````C4\```````!XGP$```````$$```%``````````````"`GP$`
M``````$$```&``````````````"0GP$```````$$```.``````````````"8
MGP$```````$$```;``````````````"@GP$```````$$```@````````````
M``"PGP$```````$$```D``````````````"XGP$```````$$```J````````
M``````#`GP$```````$$```N``````````````#(GP$```````$$```Q````
M``````````#0GP$```````$$```S``````````````#8GP$```````$$```T
M``````````````#@GP$```````$$```Y``````````````#HGP$```````$$
M```^``````````````#PGP$```````$$```_``````````````#XGP$`````
M``$$``!$``````````````!XG0$```````($```#``````````````"`G0$`
M``````($```$``````````````"(G0$```````($```'``````````````"0
MG0$```````($```(``````````````"8G0$```````($```)````````````
M``"@G0$```````($```*``````````````"HG0$```````($```+````````
M``````"PG0$```````($```,``````````````"XG0$```````($```-````
M``````````#`G0$```````($```.``````````````#(G0$```````($```0
M``````````````#0G0$```````($```1``````````````#8G0$```````($
M```2``````````````#@G0$```````($```3``````````````#HG0$`````
M``($```4``````````````#PG0$```````($```5``````````````#XG0$`
M``````($```6````````````````G@$```````($```7```````````````(
MG@$```````($```8```````````````0G@$```````($```9````````````
M```8G@$```````($```:```````````````@G@$```````($```<````````
M```````HG@$```````($```=```````````````PG@$```````($```>````
M```````````XG@$```````($```?``````````````!`G@$```````($```A
M``````````````!(G@$```````($```B``````````````!0G@$```````($
M```C``````````````!8G@$```````($```E``````````````!@G@$`````
M``($```F``````````````!HG@$```````($```G``````````````!PG@$`
M``````($```H``````````````!XG@$```````($```I``````````````"`
MG@$```````($```L``````````````"(G@$```````($```M````````````
M``"0G@$```````($```O``````````````"8G@$```````($```P````````
M``````"@G@$```````($```R``````````````"HG@$```````($```S````
M``````````"PG@$```````($```T``````````````"XG@$```````($```U
M``````````````#`G@$```````($```V``````````````#(G@$```````($
M```W``````````````#0G@$```````($```X``````````````#8G@$`````
M``($```Z``````````````#@G@$```````($```[``````````````#HG@$`
M``````($```\``````````````#PG@$```````($```]``````````````#X
MG@$```````($``!`````````````````GP$```````($``!!````````````
M```(GP$```````($``!"```````````````0GP$```````($``!#````````
M```````8GP$```````($``!%```````````````@GP$```````($``!&````
M```````````HGP$```````($``!'```````````````PGP$```````($``!(
M```````````````XGP$```````($``!)``````````````!`GP$```````($
M``!*``````````````!(GP$```````($``!+``````````````!0GP$`````
M``($``!,``````````````!8GP$```````($``!-``````````````!@GP$`
M``````($``!/``````````````#]>[^I_0,`D?U[P:C``U_6``````````#P
M>[^IT```D!&Z1OD0PC61(`(?UA\@`]4?(`/5'R`#U=```)`1OD;Y$.(UD2`"
M'];0``"0$<)&^1`"-I$@`A_6T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(V
MD2`"'];0``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y
M$*(VD2`"'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1
MXD;Y$`(WD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM``
M`)`1[D;Y$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?
MUM```)`1^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1
M(`(?UM```)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D0
M8CB1(`(?UM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:
M1_D0PCB1(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```
MD!$F1_D0(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6
MT```D!$R1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@
M`A_6T```D!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B
M.I$@`A_6T```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'
M^1"".I$@`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0
M$5Y'^1#B.I$@`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0
M``"0$6I'^1!".Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"
M'];0``"0$79'^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([
MD2`"'];0``"0$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y
M$$(\D2`"'];0``"0$8Y'^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1
MED?Y$*(\D2`"'];0``"0$9I'^1#"/)$@`A_6T```D!&>1_D0XCR1(`(?UM``
M`)`1HD?Y$`(]D2`"'];0``"0$:9'^1`B/9$@`A_6T```D!&J1_D00CV1(`(?
MUM```)`1KD?Y$&(]D2`"'];0``"0$;)'^1""/9$@`A_6_7N[J?T#`)'S4P&I
MTP``T/43`/G4``"0H$\`N:!#`9&A(P#YH0,!D0*,'OCB`P"JH#,!D8___Y?"
M``"0P```D$+\1_D`^$?YX0,"JBW__Y?```"0`,!'^0``0#F``0`U8/__EV+"
M!I%``!+X8```M2``@%*+__^7HO__EX#:1_D``$"YO___EQ^$)#F4VD?Y@`)`
MN;O__Y<!Z%,Y(0`?,@'H$SF``D"YMO__EP'H4SDA```R`>@3.0$`_)*@3T"Y
M`!0`$0!\0),?``'KR0``5,$``)````#P`&PTD2'<1_GP_O^7`/!]TW[__Y>E
M(T#Y8L(&D>0`@))``!'XH0!`^0$``/D!``#P(:`]D0$$`/G!``"P(3A`^0$(
M`/D!``#P(:P]D0$,`/F!`(!208`0N`$`@-*B3T"Y(00`D5\``6ML!0!401``
M$77"!I'C`P"J0@P`$8',(8L$`(#2'V@A^`$``-"@`E+X(:`AD07__Y?T`P`J
M@```-:`"4OA1__^7]`,`*G7"!I&@`E+X*?__EP```/``I#61]00`E&`!`+6@
M@E'XH```M0```/``>#21[P0`E*""$?A@P@:1`(!1^$```+0."P"4<\(&D6`"
M4OAX__^7F_[_E_430/G@`Q0J\U-!J?U[Q:C``U_6(Q``$:9X8?B#S".+!F@C
M^,___Q<=`(#2'@"`TN`#`)&A``#P(0`ND1_L?)(!```4_7N_J:0``/"C``#P
M`B``D?T#`)$!`$"YH```\(3$1_D%`(#28]1'^0"X1_G^_O^7P0``D,```)`A
MX`&1`.`!D2$<`)$A``#+/S@`\:D``%2A``#P(=!'^4$``+0@`!_6P`-?UL``
M`)#!``"0`.`!D2'@`9$A``#+0@"`TB'\0Y,A#,*:H0``M*(``/!"\$?Y0@``
MM$``'];``U_6P```D`'@03GA`@`U_7N^J?T#`)'S"P#Y\P,`JJ```/``Z$?Y
M@```M,```)```$#YYO[_E]C__Y>@``#P`,A'^8```+0@``#0`!`OD6O^_Y<@
M`(!28.(!.?,+0/G]>\*HP`-?UL`#7]:@``#P_7N_J?T#`)$`[$?YP```M,$`
M`)`@``#0(0`"D0`0+Y'3_O^7H```\`#@+9$!`$#YH0``M*$``/`AS$?Y00``
MM"``/];]>\&HQ?__%_]#"M&G``#P".``D0,`@-+]>[^I_0,`D>'D1_DB`$#Y
MHD\!^0(`@-*A8P"1)B``D05I8_@":6.X8R``D7\``?%"",!:PH`?^*+\8--$
M'&C30MQXTT(<<)*"``*JI/QHTX0<>)*%X$6J0@`%JL($`?@!_O]4)``(D2,@
M0/DA(`"1(C!`^26`7_A"``/*(P1`^6,`!<I"``/*0_Q?TV($`JI"?$"2(CP`
M^9\``>MA_O]4"2!`J0HL0:D``6>>80%GG@7]0M-"`6>>(OU;TZ5X"*JC#T#Y
ML'Q`DD(4":H,$$#Y+_U"T^]Y":I`'&$N`0)GGN]]0)(!`&:>(`%GGB`<8BXB
M0"*+(3./TD%0J_)C``&+0@`#BZ,30/D$`&:>0@`,BTY\0))C``&+0@`/BH0`
M"XN#``.+Q/U;TX04#JID0"2+`P(NBF,``JJB%T#YAGQ`DF,`"HM"``&+Y0$F
MBF,``HO"_4+3S?Q;TT)X#JI"?$"2K14&JHX``HK$_$+3;4`MBZ4`#JJ&>`:J
MHWU`DL9\0))$`".*K0$&BJ4`$(N$``VJ</Q;TX0`#XNN/T.I$!8#JLX!`8OO
M`0&+I0`.BV[\0M.$``^+L$`PB\-Y`ZH%?D"28WQ`DLX`)8H0`@.*S@$0JJW\
M6]/"`0*+KB-`^:T5!:K.`0&+C4`MBT(`#HND?4"2KOQ"TV\`)(K%>06JD/Q;
MTX[\0M.E?$"2$!8$JL1Y!*J$?$"2K0$%BE!`,(OO`0VJ`GY`DA`"!(JN`"**
MY@$&B\X!$*K#`0.+3?Q;TZ^[1*FM%0*J[P$!B\X!`8O&``^+8P`.BT[\0M/-
M0"V+IGU`DL)Y`JJ/`":*0GQ`DJT!`HK0_%O3SOQ"T^\!#:H0%@:JQGD&JL9\
M0)+E`06+<$`PBP-^0)(0`@:*3@`CBLX!$*K$`02+;?Q;TZ^[1:FM%0.J[P$!
MB\X!`8NE``^+A``.BV[\0M.M0"V+I7U`DL-Y`ZK/`"6*8WQ`DJT!`XJP_%O3
MKOQ"T^\!#:H0%@6JQ7D%JJ5\0)+B`0*+D$`PBP1^0)(0`@6*;@`DBLX!$*K&
M`0:+C?Q;TZ^[1JFM%02J[P$!B\X!`8M"``^+Q@`.BX[\0M--0"V+HGU`DL1Y
M!*JO`"**A'Q`DJT!!(I0_%O33OQ"T^\!#:H0%@*JPGD"JD)\0)+C`0.+T$`P
MBP9^0)(0`@**C@`FBLX!$*K%`06+S?Q;TZ^[1ZFM%0:J[P$!B\X!`8MC``^+
MI0`.B\[\0M-M0"V+HWU`DL9Y!JK&?$"23P`CBJT!!HIP_%O3[P$-JN0!!(L0
M%@.JK[=(J;!`,(L%?D"2[P$!BZT!`8NN_%O3A``/B\X5!:J10"Z+9/Q"TS)^
M0)+.`"6*@W@#JF-\0)(0`@.*;P`RBLX!$*I0_EO3P@$"BT(`#8L0%A*J4$`P
MBZ+\0M,$?D"217@%JJ5\0)(N`@6*K0`DBN\!#JJ._%O3[P$&BZ9/0/G.%02J
MQ@`!B^\!!HM&_D+3[T$NBX[\0M/&>!*JXGU`DL1Y!*K&?$"2A'Q`DA`"!HK.
M`"**[P$$BJT!$*K.`0^JHP$#B\4!!8NM.TJIK0$!B\X!`8MC``V+3?Q;TZ4`
M#HNM%0*J;4`MBZ-]0))N_%O3SA4#JJ5`+HM._$+3L'Q`DL)Y`JJ.`".*3WQ`
MDJT!#XK-`0VJK0$&BZ9;0/G!``&+!OY;TZ$!`8O&%!"J,D`FBV'\0M--?D"2
M(W@#JB%TG=)"``/*(=NM\D(`!4JE_5O30@`$BZ1?0/FE%`VJA``!BT(`!(L$
M_D+3A'@0JD)`)8MF``3*I6-`^5%\0)+&`!)*I0`!B\8`#XO&``6+I?U"TR[^
M6].M>`VJSA41JH4`#<JE``)*(OY"T\9`+HO0?$"2I4`CBZ-G0/E">!&J8P`!
MBZ4``XL#_EO38Q00JJ-`(XNE`0+*;WQ`DJ8`!DJE:T#YQ$`DBP;^0M/N_5O3
MI0`!BX0`!8O&>!"JSA4/JD4`!LJC``-*I6]`^81`+HN1?$"2I0`!BV-`+8MC
M``6+Y?U"TRW^6].E>`^JK141JF-`+8O-``7*I`$$2G!\0)*"0"*+I'-`^0W^
M6].$``&+0@`$BR3^0M.M%1"JA'@1JD)`+8NM``3*HP$#2DY\0))F0":+HW=`
M^<W]6]-C``&+Q@`#BP/^0M.M%0ZJ8W@0JL9`+8N-``/*H@$"2M%\0))%0"6+
MHGM`^2W^6]-"``&+I0`"B\+]0M.M%1&J0G@.JJ5`+8MM``+*I@$&2J]\0)+$
M0"2+IG]`^>W]6]/&``&+A``&BR;^0M.M%0^JQG@1JH1`+8M-``;*I0$%2HY\
M0)*C0".+I8-`^<W]6].E``&+8P`%B^7]0M.M%0ZJI7@/JF-`+8O-``7*I`$$
M2G!\0)*"0"*+I(=`^0W^6].$``&+0@`$B\3]0M.M%1"JA'@.JD)`+8NM``3*
MHP$#2D]\0))F0":+HXM`^>W]6]-C``&+Q@`#BP/^0M.M%0^J8W@0JL9`+8N-
M``/*H@$"2LY\0))%0"6+HH]`^<W]6]-"``&+I0`"B^+]0M.M%0ZJ0G@/JJ5`
M+8MM``+*I@$&2K%\0)+$0"2+II-`^2W^6]/&``&+A``&B\;]0M.M%1&JQG@.
MJH1`+8M-``;*I0$%2I!\0)*C0".+I9=`^0W^6].E``&+8P`%BR7^0M.M%1"J
MI7@1JF-`+8O-``7*I`$$2F]\0)*"0"*+I)M`^>[]6].$``&+0@`$BP3^0M/.
M%0^JA'@0JJT`!,I.0"Z+PGU`DJ,!`TIF0":+HY]`^4W\6]-C``&+Q@`#BZT5
M`JKC_4+3S4`MBV]X#ZJF?4"2@P`/RFX`#DJCHT#YQ4$EB\[\6]-C``&+I0`#
MB\X5!JI#_$+3KD`NBV)X`JK%?4"2XP$"RFT`#4JCIT#YI$$DBZW\6]-C``&+
MA``#BZT5!:K#_$+3C4`MBV9X!JJD?4"20P`&RF,`#DJNJT#YP0$!BX[\6]-C
M0"^+80`!B\X5!*HQ0"Z+H?Q"TR-^0)(E>`6JSP`%JL$`!8KM`0V*K0$!*H&;
ME])AX['RHD$BBZVO0/FM`0&+0@`-BVW\6].M%0.J4$`MBXW\0M,"?D"2I'D$
MJJX`!*JM``2*S@$1BLX!#2IM_$+3QD$FBZZS0/FC>0.JS@$!BXT``ZK&``Z+
M3OQ;TZT!$(K.%0*JST`NBXX``XJM`0XJYGU`DJ5!)8NMMT#YK0$!BZ4`#8O-
M_%O3K14&JK!`+8M-_$+3!7Y`DJ)Y`JIN``*J;0`"BLX!#XK.`0TJS?Q"T\1!
M)(NNNT#YIGD&JLX!`8M-``:JA``.BZ[\6].M`1"*SA4%JH]`+HM.``:*K0$.
M*N1]0)*C02.+K;]`^:T!`8MC``V+C?Q;TZT5!*IP0"V+K?Q"TP-^0)*E>06J
MS@`%JLT`!8K.`0^*S@$-*HW\0M/"02*+KL-`^:1Y!*K.`0&+K0`$JD(`#HMN
M_%O3K0$0BLX5`ZI/0"Z+K@`$BJT!#BKB?4"2ID$FBZW'0/FM`0&+Q@`-BTW\
M6].M%0*JT$`MBVW\0M,&?D"2HWD#JHX``ZJ-``.*S@$/BLX!#2I-_$+3Q4$E
MBZ[+0/FB>0*JS@$!BVT``JJE``Z+SOQ;TZT!$(K.%0:JKT`NBVX``HJM`0XJ
MY7U`DJ1!)(NMST#YK0$!BX0`#8NM_%O3K14%JI!`+8O-_$+3!'Y`DJ9Y!JI.
M``:J30`&BLX!#XK.`0TJK?Q"T\-!(XNNTT#YI7D%JLX!`8O-``6J8P`.BX[\
M6].M`1"*SA4$JF]`+HO.``6*K0$.*N-]0)*B02*+K==`^:T!`8M"``V+;?Q;
MTZT5`ZI00"V+C?Q"TP)^0)*D>02JK@`$JJT`!(K.`0^*S@$-*FW\0M/&02:+
MKMM`^:-Y`ZK.`0&+C0`#JL8`#HM._%O3K0$0BLX5`JK/0"Z+C@`#BJT!#BKF
M?4"2I4$EBZW?0/FM`0&+I0`-B\W\6].M%0:JL$`MBTW\0M,%?D"2HGD"JFX`
M`JIM``**S@$/BLX!#2K-_$+3Q$$DBZ[C0/FF>0:JS@$!BTT`!JJ$``Z+KOQ;
MTZT!$(K.%06JCT`NBTX`!HJM`0XJY'U`DJ-!(XNMYT#YK0$!BV,`#8N-_%O3
MK14$JG!`+8NM_$+3`WY`DJ5Y!:K.``6JS0`%BLX!#XK.`0TJC?Q"T\)!(HNN
MZT#YI'D$JLX!`8NM``2J0@`.BV[\6].M`1"*SA4#JD]`+HNN``2*K0$.*N)]
M0)*F02:+K>]`^:T!`8O&``V+3?Q;TZT5`JK00"V+;?Q"TP9^0)*C>0.JC@`#
MJHT``XK.`0^*S@$-*L5!)8NN\T#YS@$!BZ4`#HO._%O3SA4&JJY`+HM%_$+3
MSWU`DJ)X`JIM``*J90`"BJT!$(JM`04JQ?Q"TZ9X!JJD022+10`&JJ4`#HI.
M``:*I0`.*J-`(XNMEUZIY^1'^:T!`8NA``&+A``-B^W]6]-C``&+K14/JHU`
M+8ND?4"2COQ;T\X5!*IN0"Z+X_U"T\5]0))O>`^JH_]`^<$`#\HA``U*K?Q;
MTR)`(HO!.IC204RY\JT5!:IC``&+0@`#BX/\0M-D>`2J0D`MB^,!!,I1?$"2
M8P`.2F9`)HNC`T'Y+OY;TV,``8O&``.+SA41JJ/\0M/.0"Z+)OY"T]!]0))E
M>`6J@P`%RM%X$:IC``)*H@=!^0W^6].F`!'*0@`!BV-`+XNM%1"J8P`"B\8`
M#DH"_D+38T`MBV]\0)+$0"2+I@M!^4)X$*KM_5O3Q@`!BX0`!HLF`@+*K14/
MJL,``TJ$0"V+94`EBY)\0)*C#T'Y8P`!BTW^6].E``.+X_U"TZT5$JIC>`^J
MI4`MBT8``\JP?$"2Q@`$2J030?G&0#&+A``!BPW^6]/&``2+1/Y"TZT5$*J$
M>!*JQD`MBVT`!,JE`05*SGQ`DJ)`(HNE%T'YS?U;TZ4``8M"``6+!?Y"TZT5
M#JJE>!"J0D`MBXT`!<JF`09*47Q`DL-`(XNF&T'Y+?Y;T\8``8MC``:+QOU"
MTZT5$:K&>`ZJ8T`MBZT`!LJB`0)*;WQ`DD1`)(NB'T'Y[?U;TT(``8N$``*+
M(OY"TZT5#ZI">!&JA$`MB\T``LJC`0-*CGQ`DF5`)8NC(T'YS?U;TV,``8NE
M``.+X_U"TZT5#JIC>`^JI4`MBTT``\JD`01*L'Q`DH9`)HND)T'Y#?Y;TX0`
M`8O&``2+Q/U"TZT5$*J$>`ZJ;@`$RL9`+8O%`05*S7Q`DJ)`(HNE*T'YKOU;
MTZ4``8M"``6+!?Y"T\X5#:JE>!"JCP`%RD)`+HOF`09*3GQ`DL-`(XNF+T'Y
MQ@`!BV,`!HO&_5O3QA0.JF-`)HNF_4+3;WQ`DLUX#:JF``W*P@`"2N;]6]-$
M0"2+HC-!^<84#ZI"``&+A``"B\+]0M-">`ZJA$`FBZX!`LJ&?$"2PP$#2F5`
M)8NC-T'YSOQ;TV,``8NE``.+X_U"T\X5!JIC>`^JI4`NBTX``\JP?$"2Q`$$
M2HU`+8ND.T'Y#_Y;TX0``8NM`02+[Q40JL3\0M.O02^+[7U`DH9X!JID``;*
MA0`%2J0_0?FN_5O3A``!BZ)`(HM"``2+SA4-J@7^0M-.0"Z+L'@0JL)]0)+$
M`!#*I4-!^8\`#TJD_4+3I0`!B^-!(XM/_%O38P`%BXUX#:KO%0*JK`$,"PP0
M`/EE0"^+#P(-RNX!#DJC?$"2Q$$FBZ9'0?G&``&+A@`&BV3\6].$%`.JA``&
M"T;\0M,(`00+PG@"JF;\0M-+``L+PW@#JJ8!`LK%``5*IDM!^6H`"@O!``&+
MI4`PBZ4``8N!_%O3"BP!J2$4!*HA``4+*0`)"PD@`*FA3T'YX`!`^2```,I`
M``"TT/K_E_U[P:C_0PJ1P`-?UOU[O*G]`P"1\U,!J10`@-+U6P*I]V,#J>``
M`+2B``#0%`"`TD+@1_E7`$#YX@,`JA<!`+7@`Q2J\U-!J?5;0JGW8T.I_7O$
MJ,`#7]9"!`"10P!`.7_T`'%D&$!Z@?__5$(``$OX`P&J]@,`JO4#%ZI3?$"3
MM`)`^?3]_[3B`Q.JX0,6JN`#%*H.^O^70`$`-8!J<S@?]`!QX0``5+4"%\MS
M!@"1E`(3B[7^0Y,5`P"YX?__%[4B`)'O__\7_7N]J?T#`)'S"P#YLP``T'/F
M1_EA`D#YH1<`^0$`@-*ADP"1R/__EZ(70/EA`D#Y00`!RD$``+2/^O^7\PM`
M^?U[PZC``U_6_7N\J?T#`)'U6P*I]0,`JJ```-#S4P&IM```T/,#`*JVTP"1
M`>1'^93B1_DB`$#YHA\`^0(`@-+A`Q:JX`,5JJ___Y?@``"U8.9'^:$?0/D`
M`$#Y(```RD`!`+1T^O^7H#>`N8$"0/D@#`"+`01`^0$``/DA_O^T`"``D?S_
M_Q?S4T&I]5M"J?U[Q*C``U_6_7NZJ?T#`)'S4P&IM```T/5;`JGU`P&J]V,#
MJ?8#`*KY:P2I@.9'^0$`0/FA+P#Y`0"`TJ`"0#D?]`!QM1:5FN`#%:I2^O^7
M]P,`JJ%3`9'@`Q:JAO__ER`"`+3S`P"J2_K_E_\"`.MH!@!4``"`TJ%J8#AA
M:B`X``0`D:'__S4``(!2E.9'^:(O0/F!`D#Y00`!RL$)`+1!^O^7LP``T&#B
M1_D9`$#Y``"`TO@#`"H`!`"1(0\`BR&`7_B!__^UH0``\``+`!$BL$"Y(@$`
M-`%\?9/@`QFJ3?G_EV'B1_D@``#YP`$`M0``@!+F__\7`'Q]DR(`@%(BL`"Y
MA/G_E_H#`*H@__^T`G]]D^$#&:J#^?^78.)'^1H``/ESXD?Y`']`DP`$`)%A
M`D#Y/W@@^+A7`+GA`Q:J(`!`.1_T`'$$&$!Z`00`5+,``-"X5X"Y(0`6R^`*
M`)%SXD?Y`,`ABQCS?=-Y`D#Y:?G_ER!K./C`^_^T8`)`^:%7@+D#>&'X``"`
MTL%J8#AB``"+/_0`<6%H(#@D&$!Z``0`D4'__U2@!X!20```.0``@-)#``"+
MH6I@.``$`)%A!``Y@?__-;#__Q<A!`"1W/__%_-30:GU6T*I]V-#J?EK1*G]
M>\:HP`-?UOU[LJG]`P"1\U,!J;0``-#U6P*I]V,#J?EK!*F!YD?Y(@!`^:)O
M`/D"`(#28`(`M`$`0#GU`P"J`0(`-._X_Y?W`P"JH`$`M!@``+`9``"P&%<S
MD3E3,Y&Z8P&1X`,7JAKY_Y=@`0"UX`,7JD/Y_Y?@`Q6JG?G_EY3F1_FA;T#Y
M@`)`^2```,I@!0"TR_G_EQ-,`)'A`QBJX`,3J@?Y_Y?@_?\TX0,9JN`#$ZH#
M^?^78/W_-.`#%:J\^?^7]@,`JN`#$ZJY^?^7```6"P`(`!$`?$"3%?G_E_8#
M`*H!``"PXP,3JN(#%:HA7#.1G_G_E^$#&JK@`Q:JC/G_EQ\$`#%``0!4H&M`
MN0`,%!(?$$!QP0``5.`#%JJZ__^7X`,6JG[Y_Y?.__\7X`,6JOOX_Y?[__\7
M\U-!J?5;0JGW8T.I^6M$J?U[SJC``U_6_7N^J?T#`)'S4P&ILP``T/0#`*IS
MVD?Y8`)`N7SY_Y<!``B1X`,4JOWX_Y>@```T``"`4O-30:G]>\*HP`-?UF`"
M0+ER^?^7`!!"N0`,%!(?$$!QX0``5.`#%*I!`(!2I_C_EQ\``''@%Y\:\O__
M%V`"0+EF^?^7`!!"N0`,%!(?*$!Q8?W_5/3__Q>@``#0_7N_J?T#`)$`V$?Y
M``!`N5OY_Y>B``#0`P``L`$``+!CH#*1_7O!J"%T,Y%"]$?Y2_G_%_U[OJG]
M`P"1\PL`^;,``-!SVD?Y8`)`N4SY_Y?K__^78`)`N4GY_Y?S"T#Y!```L`(`
M`+"$G#V1`0``L/U[PJCC`P2J0I`CD2'D,Y$%`(!2@OC_%_\+0-'_@P#1_7N]
MJ?T#`)'U6P*IM@``T/-3`:FTXP"1P.9'^0$`0/FA)Q#Y`0"`TH7X_Y?C`P`J
M!```L`(``+"$.#210D@TD>`#%*HA`(+2:?C_EQ\$`#$A`0!4`P"`TL'F1_G@
M`P.JHB=0^2$`0/E!``'*(04`M#?Y_Y<!?$"3/P1`\4D``%0`?2#4@/[_-P`(
M@M("`(+2LP,`B^`#%*KA`Q.JR/C_E_4#`*J`_?\W``0`$0!\0).#^/^7XP,`
MJN#\_[0?`!/KM'Y`DX(``%0``!2+?P(`ZX/]_U1_`!/KB0``5&`"%(M_``#K
MX_S_5"``@E*_`@!KC/S_5.`#`ZKB`Q2JX0,3J@/Y_Y?C`P"J'V@T.-/__Q?S
M4T&I]5M"J?U[PZC_"T"1_X,`D<`#7]:T__\7_P=`T?]#`-']>[JI_0,`D?-3
M`:FT``#0]5L"J?4#`*KY:P2I\P,!JO=C`ZF`YD?Y^RL`^0$`0/FA-PCY`0"`
MT@```+``>#216?[_E_H#`*K@`Q6JX06`4GKX_Y>``0"T````L.$#%:H`G#21
MAO[_EY3F1_G@`Q6JHC=(^8$"0/E!``'*`0H`M.;X_Y?@`Q6J%@``L!<``+`9
M``"P]U8SD3G;-)';^/^7^`,`*L'2-)'@`Q.J&`<`$;[X_Y?S`P"J$_W_M&`"
M0#D?``!Q\P*3FEH!`+3A`Q.JX`,:JA'X_Y?````UP=(TD0``@-*Q^/^7\P,`
MJO/__Q?@`Q.JQ?C_EV'"((LA\%\X/[P`<2`"`%0``P`+'_P_<4SZ_U2[HP&1
M`@``L.4#%:KD`QFJXP,3JD)`.)'@`QNJ`0""TN'W_Y<`!``1'P1`<:D``%0`
M?2#4``0`47_*(#CJ__\7LP``T'/:1_E@`D"YEOC_EP$`")'@`QNJA_C_EV#[
M_S5@`D"YD/C_EP`00KD`#!02'R!`<:'Z_U3@`QNJ(0"`4L7W_Y<@^O\U````
ML.$#&ZH`G#21-?[_E^`#&ZH.^/^7]0,`JJS__Q?S4T&I]5M"J?=C0ZGY:T2I
M^RM`^?U[QJC_!T"1_T,`D<`#7]8!!`"1(O!?.$(``#7``U_67[P`<0`0@9HA
M!`"1^O__%\`'`+3]>[ZI_0,`D?-3`:GS`P"J%`!`.=0``#4```"P`%0SD?-3
M0:G]>\*H[_?_%W;X_Y<"!`#18@("BW\"`NNB`@!40`!`.1^\`'&@`0!40`!`
M.1^\`'&!`0!40@0`T7\"`NMC`@!40@`3RT`(`)$?!$#Q:0(`5```@-(<```4
M0@0`T>[__Q="!`#1?P("ZP/^_U1_`@+K(?[_5)^^`''@^_]4````L`#8-)'>
M__\70`!`.1^\`'$@_?]4Z___%T($`)%?!$#Q20``5`!](-2T``#PX0,3JI3"
M`I&4(@"1X`,4JNWW_Y?@`Q2J\U-!J?U[PJC``U_6````L`!4,Y'+__\7_7NY
MJ?T#`)'S4P&ILP``T/5;`JD6``"P]QL`^1<``+!@YD?Y%```L!4``+`!`$#Y
MH3<`^0$`@-(```"P`*`RD;7^-9$`*`"1`@Q`J:(/!*D"#$&I`$!`>:(/!:F@
MPP!Y````L`#@-)&@_?^7````L``$-9&=_?^7````L``D-9&:_?^7````L`!(
M-9&7_?^7P&8UD97]_Y<```"P`*0UD9+]_Y?@>C21D/W_EX#6-9&._?^7X`,5
MJHS]_Y<```"P`"0VD8G]_Y<```"P`)PTD8;]_Y<```"P`$PVD7']_Y>```"T
MX0,`JN`#%:JC_?^7````L`"0-I%J_?^7H```M.$#`*H```"P`-@VD9O]_Y<`
M``"P``0WD6+]_Y?``0"TX0,`JN!Z-)&4_?^7`0``L,!F-9$A$#R1D/W_EW/F
M1_FA-T#Y8`)`^2```,H@`@"T\??_EP```+``1#>14?W_E^$#`*H@`0"U`0``
ML*!'`9$AB#>10@&`TK4#`9%*]_^78/W_-:%N`)&`UC61Y___%_-30:GU6T*I
M]QM`^?U[QZC``U_6_7N^J?T#`)'S"P#YLP``\&`*0+D?!``QH0$`5````+``
MU#61-OW_EP$`@%+@``"T``!`.1\``''A!Y\:'\``<>`'GQHA```*80H`N6`*
M0+GS"T#Y_7O"J,`#7];]>[^I_0,`D<?W_Y=2]_^7X0,`J@``@-)!``"T(`!`
M^?U[P:C``U_6_7N]J?T#`)'U6P*I%0``L+:V-Y'S4P&I\P,`JN`#%JH6_?^7
M@```M`$`0#GT`P"JX0``->$#$ZJ@MC>1\U-!J?5;0JG]>\.H0OW_%^$#$ZHC
M]_^7@`(`M>`#$ZJ@]_^7]0,`JN`#%*J=]_^7H`(`BP`(`)'Z]O^7]0,`J@,`
M`+`!``"P(4`XD>0#%*ICT#21X@,3JH+W_Y?A`Q6JX`,6JN?__Q?S4T&I]5M"
MJ?U[PZC``U_6_R-`T0(UD-+_0P71_7NZJ?T#`)'Y:P2IN@``T/5;`JGV`P"J
M\U,!J:$#`HOW8P.IMP,"D?MS!:FUPP*10.='^;1C`I$;``"0`@!`^2(``/D"
M`(#2H```T``@`)$!(`"1(@Q`J>(.`*D"#$*IH@X`J0(,0ZFB#@&I`@Q$J0$,
M0/FB#@*I`@Q%J>$*`/D`,$#Y@@X`J8`*`/E@>S21ROS_E[L_`/D@`@"T`0!`
M.?,#`*K!`0`TIO__E^`#$ZK3]O^7]`,`JEKG1_D!-9#2H0,!B^`#%*HB`$#Y
M00-`^4$``<I!0`"T5??_EX___Y?S`P"J``(`M1@`@-(`:W3X@```M1,``)!S
M]C>1"@``%*[\_Y<3`(#2H```M`$`0#EA```TNO;_E_,#`*H8(P"1<_[_M.`#
M$ZH9``"0.1,XD3OW_Y<`^'_3``0`D9CV_Y?X`P"J]`,`JF("0#D""``U$P"`
MTG1J=?B4`0"TX`,4JI;\_Y?T`P"JX`<`M`$`0#FA!P`TD_W_EV`'`#3@`Q2J
MG_;_E_0#`*H5`(#2M```M;-J=_AS``"T8`)`.8`&`#7@`Q2J%0``D!WW_Y?S
M`P"JX`,8JAKW_Y<3`!,+<Q(0$7-^0)/@`Q.J=?;_E_<#`*H$``"0`0``D.4#
M&*J$)#B1H]HTD>(#%*HA.#B1_/;_E^`#%ZH!.(!2X?;_EQ\$`#%A!`!4VO;_
MEP``0+D?1`!QX`,`5*```+#4`D#Y`+Q'^1,`0/G2]O^7`0``D`0`0+GC`Q>J
MX@,4JB%<.)'@`Q.JK_;_EQ0`@-*<__\7X`,4JN$#&:IS!@"1E`H`D>#V_Y>Z
M__\7<R(`D;O__Q?@`Q.J5/W_EX```#3@`Q.J8/;_E_0#`*JU(@"1P?__%[0`
M`+"4VD?Y@`)`N<WV_Y<!``B1X`,7JD[V_Y?X`P`J8#``-8`"0+G&]O^7`!!"
MN0`,%!(?$$!QH2\`5(`"0+G`]O^7&1A"N=KV_Y<_`P!KX2X`5(`"0+FZ]O^7
M`!!"N0`@`!(?``=Q(2X`5.`#$ZHH]O^7]`,`J@```)``X#>1*_S_EP`!`+33
M`D#Y.?;_E^$#`*K@`Q.JNOW_E_,#`*I```"UTP)`^>`#$ZJY]O^7'PP`<?D#
M`*J-`P!4`'Q`DP$``)``$`#1(4@YD6`"`(OT]?^7H`(`-3\3`''```!4.1,`
M47G".8L@\U\X'[P`<<$!`%36!D#YE@$`M.`#%JJD]O^7'PP`\0D!`%0`$`#1
M`0``D"%<.9'``@"+X?7_EQ\``'%S$I::PO[_ER`C`#7@`Q.J`0"`4A+V_Y?Y
M`P`J@"(`-$(`@%(A`H"2MJ,&D<SU_Y?A`Q:JX`,9*L(`@-)4]O^7H*-&.4`%
M`#6@IT8Y'PP!<>$$`%2@JT8Y'P0!<8$$`%2@KT8Y'PP!<2$$`%2@LT8Y'R`!
M<<$#`%2@MT8Y'Q0!<6$#`%3@`QDJ0@"`4B$'@)*S]?^7X0,6JN`#&2HB!8#2
M._;_EP4``)#D`Q:JI9P]D0$``)"CVC21X@,7JB%P.9'@`Q2J6O;_E^`#%ZI$
M]O^7H#]`^>$#%*H`>#21`?S_E^`#%*JK_O^7"/__%^`#&2H"`(!2`0"`TKB#
M`Y$<XP"1E_7_E[__$*D@8(32OUL!N:#HK/*@<P#Y('&5TJ#YO?*@=P#YP)^;
MTD`7L_*@>P#YP(Z*TD`&HO*@?P#Y`#Z<TD!ZN/*@@P#Y`.,!D:`[`/GA`Q:J
MX`,9*@(`D-(,]O^7'P``<>4#`*KS`P`J;`P`5.`#&2K^]?^7L]M0J:%C!)'C
M#X`28")#TP($`!$`?$"37^``<2-H(#A`?$"3K14`5`$(@%(9XP"1(@`"2R`#
M`(L!`(!20GQ`DX'U_Y?@`QBJ$_?_E^`#&:H"!X#2`0"`4GOU_Y>V3P4YP/Y8
MT[-?!3FY@P61H$,%.<#^4-.@1P4YP/Y(TQ8``)"@2P4Y8/Y8T]82.)&@4P4Y
M8/Y0TZ!7!3E@_DC3$P"`TJ!;!3G@`QBJN.,%D?KV_Y>@<T#YH(\%.0'\6-.A
M@P4Y`?Q0TZ&'!3D!_$C3H'=`^:&+!3F@GP4Y`?Q8TZ&3!3D!_%#3H9<%.0'\
M2-.@>T#YH9L%.:"O!3D!_%C3H:,%.0'\4-.AIP4Y`?Q(TZ!_0/FAJP4YH+\%
M.0'\6-.ALP4Y`?Q0TZ&W!3D!_$C3H(-`^:&[!3F@SP4Y`?Q8TZ'#!3D!_%#3
MH<<%.0'\2-.ARP4Y8FIY.``'$XOA`Q:J<P8`D=7U_Y=_4@#Q0?__5`4``)"_
M@P8YI9P]D>0#&*IO__\7H8=`^:!\0),B#``+/P`"ZXD``%2ABT#Y(00`D:&+
M`/FABT#Y('1`BZ*#$*F@6T&Y8`0`-!,(@%)S`@!+@,,@B[\`$VNST),:'P`6
MZWM^0)."``!4`0`;B]\"`>O#``!4'P`6ZZD``%3!`AN+'P`!ZT(``%0`?2#4
M?R-`\:4W`/FH__]4X@,;JN$#%JJN]?^7H%M!N:4W0/E@`@`+'P`!<:!;`;FA
M[?]4LP`32]L"&XO@`QBJF/;_EP(``!3[`Q:J?_X`<6P"`%1_`QSK8GY`DXD`
M`%2``P*+?P,`Z\/\_U1_`QSK@@``5&`#`HN?`P#K(_S_5%\@`?'H^_]4X0,;
MJN`#'*J0]?^7LUL!N5/__Q>@.T#YGP,;ZP`P6_K(^O]4?P,<ZV,#`9%B``!4
MGP,#ZR/Z_U3A`QNJX`,<J@((@-*C-P#Y<P(!47_U_Y>C-T#Y^P,#JM?__Q<!
M!X!2`^,`D2(``DM@``"+`0"`4D)\0)-:__\7`0``D````)`A$#R1`-0UD1,`
M`)"UVC21<YX]D18``)`5^_^7UN8YD;;T_Y?D`P`J`0``D.4#$ZKC`Q6JX@,7
MJB&L.9'@`Q2J7O7_E^`#%*H!.(!20_7_EQ\$`#$!X/]4//7_EP``0+D?1`!Q
M@=__5*3T_Y<8!P`1Y`,`*N8#$ZKE`Q@JXP,5JN(#%ZKA`Q:JX`,4JDOU_Y?M
M__\7H```L`$``)#"`D#YXP,7JB$H.I$`O$?Y``!`^0KU_Y=;_O\7\U-!J?5;
M0JGW8T.I^6M$J?MS1:G]>\:H_R-`D?]#!9'``U_6_7NZJ?T#`)'S4P&ILP``
ML/5;`JGW8P.I=-I'^?EK!*G[<P6I@`)`N2GU_Y?U`P"J@`)`N2;U_Y<`X$(Y
MH.8".0```)``9#61G/K_E\```+0!`$`Y/\0`<6$``%0`!$`Y0```-.W\_Y=U
MVD?YM```\*`"0+D6]?^7`0``D&,!@%(A=#N1(@"`4JWT_Y<@!`"U=MI'^<`"
M0+D-]?^7`0``D&,`@%(AB#N1(@"`4J3T_Y?U`P"JX`D`M7;:1_G``D"Y`_7_
MEP$``)!C`(!2(:0[D2(`@%*:]/^7]0,`JB`,`+0```"0`)PTD73Z_Y?W`P"J
M(`H`M,`"0+GU]/^7H0I`^>(#%ZHA`$#YE?3_EU4``!0`"$#Y&X"`4IK"!I$6
M`(!2&P2@<AD40/E`@U"XUP8`$?\"`&LJ`0!4H`)`N>3T_Y?"?D"3X0,9J@,`
M@%)$]/^7^`,`JD`"`+6`P@:1`8!0N"$$`%'?`@%K0?G_5'?:1_GU`P"J-@"`
M4J""4+C?`@!KBOC_5.`"0+G6!@`1T/3_E^$#&:KZ\_^7^/__%P$`0/E``U'X
M'-AW^"`,0+D``!L*'P`0<0$!`%0@"$#YX0,`JN`#'*H:]/^7@/S_-?8#%RK6
M__\7H`)`N;WT_Y<!`T#Y0P"`4@(`@-+)]/^7]/__%\`"0+FV]/^7H0I`^0(`
M`)!"D#N1(0!`^57T_Y>@"D#Y``!`^0`,0+D`];<VP`)`N:OT_Y>A"D#Y(0!`
M^13T_Y>B__\7:?O_E_<#`*K``D"Y]P0`M*+T_Y>A"D#YX@,7JB$`0/E"]/^7
MX`,7JHST_Y=SVD?Y8`)`N9GT_Y?U`P"J8`)`N9;T_Y<!``"0(@"`4B&L.Y'*
M\_^7X0,`J@(``)#@`Q6J0@`\D3'T_Y=@`D"YD\(&D8KT_Y<?Y`(Y````D`!X
M-)$!^O^78((1^,`!`+5@`E'X#/W_EV""$?A``0"U````D``8/)'%\_^7?/3_
MEX'"!I$B`%'XH0I`^4(`0/F%__\7E,(&D0$X@%*`@E'X7_3_EP$$`!$_!`!Q
M!(A1>N```%2!"G&IXP,`*@```)``G#R1(0!`^;'S_Y?S4T&I]5M"J?=C0ZGY
M:T2I^W-%J?U[QJC``U_6_7N^J?T#`)'S4P&I\P,`JN_[_Y?F^_^7]`,`JI;\
M_Y<?``!Q9!I`^J`!`%1@`D`Y8`$`-`$``)#@`Q2J(20XD>7S_Y>?`@#KH0``
M5.`#$ZKS4T&I_7O"J'7Z_Q?S4T&I_7O"J,`#7];]>[^I_0,`D?U[P:C``U_6
M`````'!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(```+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E<P!005)?5$5-4`!005)?
M4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/
M`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%
M0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U0
M1$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%
M04X`4$%27T-,14%./0!,1%],24)205)97U!!5$@`4UE35$5-`"4P,G@`<&%R
M+0`E<R5S)7,E<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`'!A<FP`+G!A<@`E<R5S8V%C:&4M
M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!!4D=6`!@`<&5R;``P`%!!
M4CHZ4&%C:V5R.CI615)324].`#$N,#0Q`%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`+64`+2T`55-%4@!5
M4T523D%-10!414U01$E2`%1-4``O=&UP`&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC
M:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL
M96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES
M=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*
M;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@
M)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE
M('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A
M9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S
M970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I
M9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@
M,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@
M/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@
M=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T
M85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y
M.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@
M+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F
M?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D
M9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE
M(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET
M=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@
M)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S
M=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D
M9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L
M;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O
M<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*
M)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B
M)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F
M*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA
M9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S
M93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*
M57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@
M72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*
M;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I
M;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q
M=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I
M(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````%`A````````Z"````````````````````$``````````0`````````!
M`````````/4"````````#P````````"G`P````````P`````````&!H`````
M```-`````````)1,````````&0````````!HFP$``````!L`````````"```
M```````:`````````'";`0``````'``````````(`````````/7^_V\`````
MZ`$````````%`````````+@,````````!@````````#(`@````````H`````
M````I`0````````+`````````!@`````````%0````````````````````,`
M````````8)T!```````"`````````-`%````````%``````````'````````
M`!<`````````2!0````````'`````````&`1````````"`````````#H`@``
M``````D`````````&``````````8````````````````````^___;P`````!
M```(`````/G__V\`````$```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#`:````````
M,!H````````P&@```````#`:````````,!H````````P&@```````#`:````
M````,!H````````P&@```````#`:````````,!H````````P&@```````#`:
M````````,!H````````P&@```````#`:````````,!H````````P&@``````
M`#`:````````,!H````````P&@```````#`:````````,!H````````P&@``
M`````#`:````````,!H````````P&@```````#`:````````,!H````````P
M&@```````#`:````````,!H````````P&@```````#`:````````,!H`````
M```P&@```````#`:````````,!H````````P&@```````#`:````````,!H`
M```````P&@```````#`:````````,!H````````P&@```````#`:````````
M,!H````````P&@```````#`:````````,!H````````P&@```````#`:````
M````,!H````````P&@```````#`:````````,!H````````P&@```````#`:
M````````,!H````````P&@```````#`:````````,!H```````"`FP$`````
M`#`>`````````````````````````````)1,````````````````````````
M````````````````&!H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P````"(3P```````-5,````````````
M``````"V30```````*]-````````?$\```````#,30```````(1/````````
M``````````!N3P```````'-/``````````````````"-3P```````$=#0SH@
M*$%L<&EN92`V+C0N,"D@-BXT+C```"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N
M9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M```````````````````````````````````+`````0````(`````````R`$`
M``````#(`0```````!H````````````````````!````````````````````
M$P```/;__V\"`````````.@!````````Z`$```````#<``````````,`````
M````"````````````````````!T````+`````@````````#(`@```````,@"
M````````\`D````````$`````P````@`````````&``````````E`````P``
M``(`````````N`P```````"X#````````*0$```````````````````!````
M````````````````+0````0````"`````````&`1````````8!$```````#H
M`@````````,`````````"``````````8`````````#<````$````0@``````
M``!(%````````$@4````````T`4````````#````$0````@`````````&```
M``````!!`````0````8`````````&!H````````8&@```````!``````````
M```````````$````````````````````/`````$````&`````````#`:````
M````,!H`````````!```````````````````$``````````0`````````$<`
M```!````!@`````````P'@```````#`>````````9"X`````````````````
M``0```````````````````!-`````0````8`````````E$P```````"43```
M`````!`````````````````````$````````````````````4P````$````"
M`````````*A,````````J$P````````9/P``````````````````"```````
M`````````````%L````!`````@````````#$BP```````,2+````````!```
M``````````````````0```````````````````!E````#@````,`````````
M:)L!``````!HFP````````@````````````````````(``````````@`````
M````<0````\````#`````````'";`0``````<)L````````(````````````
M````````"``````````(`````````'T````!`````P````````!XFP$`````
M`'B;````````"`````````````````````@```````````````````""````
M!@````,`````````@)L!``````"`FP```````.`!````````!``````````(
M`````````!``````````BP````$````#`````````&"=`0``````8)T`````
M``"@`@``````````````````"``````````(`````````)`````!`````P``
M````````H`$```````"@````````>`````````````````````@`````````
M``````````"6````"`````,`````````>*`!``````!XH````````&`0````
M```````````````(````````````````````FP````$````P````````````
M````````>*`````````:`````````````````````0`````````!````````
M``$````#`````````````````````````)*@````````I```````````````
4``````$`````````````````````
